rnalysis.filtering.DESeqFilter.split\_by\_ref\_table\_attr
==========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: DESeqFilter.split_by_ref_table_attr